grib2io.tables.originating_centers API documentation

# grib2io.tables.originating_centers

View Source

    table_originating_centers  = {
    '1':'Melbourne (WMC)',
    '2':'Melbourne (WMC)',
    '3':'Melbourne (WMC)',
    '4':'Moscow (WMC)',
    '5':'Moscow (WMC)',
    '6':'Moscow (WMC)',
    '7':'US National Weather Service - NCEP (WMC)',
    '8':'US National Weather Service - NWSTG (WMC)',
    '9':'US National Weather Service - Other (WMC)',
    '10':'Cairo (RSMC/RAFC)',
    '11':'Cairo (RSMC/RAFC)',
    '12':'Dakar (RSMC/RAFC)',
    '13':'Dakar (RSMC/RAFC)',
    '14':'Nairobi (RSMC/RAFC)',
    '15':'Nairobi (RSMC/RAFC)',
    '16':'Casablanca (RSMC)',
    '17':'Tunis (RSMC)',
    '18':'Tunis-Casablanca (RSMC)',
    '19':'Tunis-Casablanca (RSMC)',
    '20':'Las Palmas (RAFC)',
    '21':'Algiers (RSMC)',
    '22':'ACMAD',
    '23':'Mozambique (NMC)',
    '24':'Pretoria (RSMC)',
    '25':'La Reunion (RSMC)',
    '26':'Khabarovsk (RSMC)',
    '27':'Khabarovsk (RSMC)',
    '28':'New Delhi (RSMC/RAFC)',
    '29':'New Delhi (RSMC/RAFC)',
    '30':'Novosibirsk (RSMC)',
    '31':'Novosibirsk (RSMC)',
    '32':'Tashkent (RSMC)',
    '33':'Jeddah (RSMC)',
    '34':'Tokyo (RSMC), Japanese Meteorological Agency',
    '35':'Tokyo (RSMC), Japanese Meteorological Agency',
    '36':'Bankok',
    '37':'Ulan Bator',
    '38':'Beijing (RSMC)',
    '39':'Beijing (RSMC)',
    '40':'Seoul',
    '41':'Buenos Aires (RSMC/RAFC)',
    '42':'Buenos Aires (RSMC/RAFC)',
    '43':'Brasilia (RSMC/RAFC)',
    '44':'Brasilia (RSMC/RAFC)',
    '45':'Santiago',
    '46':'Brazilian Space Agency - INPE',
    '47':'Columbia (NMC)',
    '48':'Ecuador (NMC)',
    '49':'Peru (NMC)',
    '50':'Venezuela (NMC)',
    '51':'Miami (RSMC/RAFC)',
    '52':'Miami (RSMC), National Hurricane Center',
    '53':'Canadian Meteorological Service - Montreal (RSMC)',
    '54':'Canadian Meteorological Service - Montreal (RSMC)',
    '55':'San Francisco',
    '56':'ARINC Center',
    '57':'US Air Force - Air Force Global Weather Center',
    '58':'Fleet Numerical Meteorology and Oceanography Center,Monterey,CA,USA',
    '59':'The NOAA Forecast Systems Lab, Boulder, CO, USA',
    '60':'National Center for Atmospheric Research (NCAR), Boulder, CO',
    '61':'Service ARGOS - Landover, MD, USA',
    '62':'US Naval Oceanographic Office',
    '63':'International Research Institude for Climate and Society',
    '64':'Honolulu',
    '65':'Darwin (RSMC)',
    '66':'Darwin (RSMC)',
    '67':'Melbourne (RSMC)',
    '68':'Reserved',
    '69':'Wellington (RSMC/RAFC)',
    '70':'Wellington (RSMC/RAFC)',
    '71':'Nadi (RSMC)',
    '72':'Singapore',
    '73':'Malaysia (NMC)',
    '74':'U.K. Met Office - Exeter (RSMC)',
    '75':'U.K. Met Office - Exeter (RSMC)',
    '76':'Moscow (RSMC/RAFC)',
    '77':'Reserved',
    '78':'Offenbach (RSMC)',
    '79':'Offenbach (RSMC)',
    '80':'Rome (RSMC)',
    '81':'Rome (RSMC)',
    '82':'Norrkoping',
    '83':'Norrkoping',
    '84':'French Weather Service - Toulouse',
    '85':'French Weather Service - Toulouse',
    '86':'Helsinki',
    '87':'Belgrade',
    '88':'Oslo',
    '89':'Prague',
    '90':'Episkopi',
    '91':'Ankara',
    '92':'Frankfurt/Main (RAFC)',
    '93':'London (WAFC)',
    '94':'Copenhagen',
    '95':'Rota',
    '96':'Athens',
    '97':'European Space Agency (ESA)',
    '98':'European Center for Medium-Range Weather Forecasts (RSMC)',
    '99':'De Bilt, Netherlands',
    '100':'Brazzaville',
    '101':'Abidjan',
    '102':'Libyan Arab Jamahiriya (NMC)',
    '103':'Madagascar (NMC)',
    '104':'Mauritius (NMC)',
    '105':'Niger (NMC)',
    '106':'Seychelles (NMC)',
    '107':'Uganda (NMC)',
    '108':'United Republic of Tanzania (NMC)',
    '109':'Zimbabwe (NMC)',
    '110':'Hong-Kong',
    '111':'Afghanistan (NMC)',
    '112':'Bahrain (NMC)',
    '113':'Bangladesh (NMC)',
    '114':'Bhutan (NMC)',
    '115':'Cambodia (NMC)',
    '116':'Democratic Peoples Republic of Korea (NMC)',
    '117':'Islamic Republic of Iran (NMC)',
    '118':'Iraq (NMC)',
    '119':'Kazakhstan (NMC)',
    '120':'Kuwait (NMC)',
    '121':'Kyrgyz Republic (NMC)',
    '122':'Lao Peoples Democratic Republic (NMC)',
    '123':'Macao, China',
    '124':'Maldives (NMC)',
    '125':'Myanmar (NMC)',
    '126':'Nepal (NMC)',
    '127':'Oman (NMC)',
    '128':'Pakistan (NMC)',
    '129':'Qatar (NMC)',
    '130':'Yemen (NMC)',
    '131':'Sri Lanka (NMC)',
    '132':'Tajikistan (NMC)',
    '133':'Turkmenistan (NMC)',
    '134':'United Arab Emirates (NMC)',
    '135':'Uzbekistan (NMC)',
    '136':'Viet Nam (NMC)',
    '137-139':'Reserved',
    '140':'Bolivia (NMC)',
    '141':'Guyana (NMC)',
    '142':'Paraguay (NMC)',
    '143':'Suriname (NMC)',
    '144':'Uruguay (NMC)',
    '145':'French Guyana',
    '146':'Brazilian Navy Hydrographic Center',
    '147':'National Commission on Space Activities - Argentina',
    '148':'Brazilian Department of Airspace  Control - DECEA',
    '149':'Reserved',
    '150':'Antigua and Barbuda (NMC)',
    '151':'Bahamas (NMC)',
    '152':'Barbados (NMC)',
    '153':'Belize (NMC)',
    '154':'British Caribbean Territories Center',
    '155':'San Jose',
    '156':'Cuba (NMC)',
    '157':'Dominica (NMC)',
    '158':'Dominican Republic (NMC)',
    '159':'El Salvador (NMC)',
    '160':'US NOAA/NESDIS',
    '161':'US NOAA Office of Oceanic and Atmospheric Research',
    '162':'Guatemala (NMC)',
    '163':'Haiti (NMC)',
    '164':'Honduras (NMC)',
    '165':'Jamaica (NMC)',
    '166':'Mexico City',
    '167':'Netherlands Antilles and Aruba (NMC)',
    '168':'Nicaragua (NMC)',
    '169':'Panama (NMC)',
    '170':'Saint Lucia (NMC)',
    '171':'Trinidad and Tobago (NMC)',
    '172':'French Departments in RA IV',
    '173':'US National Aeronautics and Space Administration (NASA)',
    '174':'Integrated System Data Management/Marine Environmental Data Service (ISDM/MEDS) - Canada',
    '175':'Reserved',
    '176':'US Cooperative Institude for Meteorological Satellite Studies',
    '177-189':'Reserved',
    '190':'Cook Islands (NMC)',
    '191':'French Polynesia (NMC)',
    '192':'Tonga (NMC)',
    '193':'Vanuatu (NMC)',
    '194':'Brunei (NMC)',
    '195':'Indonesia (NMC)',
    '196':'Kiribati (NMC)',
    '197':'Federated States of Micronesia (NMC)',
    '198':'New Caledonia (NMC)',
    '199':'Niue',
    '200':'Papua New Guinea (NMC)',
    '201':'Philippines (NMC)',
    '202':'Samoa (NMC)',
    '203':'Solomon Islands (NMC)',
    '204':'Narional Institude of Water and Atmospheric Research - New Zealand',
    '205-209':'Reserved',
    '210':'Frascati (ESA/ESRIN)',
    '211':'Lanion',
    '212':'Lisbon',
    '213':'Reykjavik',
    '214':'Madrid',
    '215':'Zurich',
    '216':'Service ARGOS - Toulouse',
    '217':'Bratislava',
    '218':'Budapest',
    '219':'Ljubljana',
    '220':'Warsaw',
    '221':'Zagreb',
    '222':'Albania (NMC)',
    '223':'Armenia (NMC)',
    '224':'Austria (NMC)',
    '225':'Azerbaijan (NMC)',
    '226':'Belarus (NMC)',
    '227':'Belgium (NMC)',
    '228':'Bosnia and Herzegovina (NMC)',
    '229':'Bulgaria (NMC)',
    '230':'Cyprus (NMC)',
    '231':'Estonia (NMC)',
    '232':'Georgia (NMC)',
    '233':'Dublin',
    '234':'Israel (NMC)',
    '235':'Jordan (NMC)',
    '236':'Latvia (NMC)',
    '237':'Lebanon (NMC)',
    '238':'Lithuania (NMC)',
    '239':'Luxembourg',
    '240':'Malta (NMC)',
    '241':'Monaco',
    '242':'Romania (NMC)',
    '243':'Syrian Arab Republic (NMC)',
    '244':'The former Yugoslav Republic of Macedonia (NMC)',
    '245':'Ukraine (NMC)',
    '246':'Republic of Moldova (NMC)',
    '247':'Operational Programme for the Exchange  of Weather RAdar Information (OPERA) - EUMETNET',
    '248-249':'Reserved',
    '250':'COnsortium for Small scale MOdelling (COSMO)',
    '251-253':'Reserved',
    '254':'EUMETSAT Operations Center',
    '255':'Missing Value',
    }

    table_originating_subcenters  = {
    '1':'NCEP Re-Analysis Project',
    '2':'NCEP Ensemble Products',
    '3':'NCEP Central Operations',
    '4':'Environmental Modeling Center',
    '5':'Weather Prediction Center',
    '6':'Ocean Prediction Center',
    '7':'Climate Prediction Center',
    '8':'Aviation Weather Center',
    '9':'Storm Prediction Center',
    '10':'National Hurricane Center',
    '11':'NWS Techniques Development Laboratory',
    '12':'NESDIS Office of Research and Applications',
    '13':'Federal Aviation Administration',
    '14':'NWS Meteorological Development Laboratory',
    '15':'North American Regional Reanalysis Project',
    '16':'Space Weather Prediction Center',
    '17':'ESRL Global Systems Division',
    }

    table_generating_process  = {
    '0-1':'Reserved',
    '2':'Ultra Violet Index Model',
    '3':'NCEP/ARL Transport and Dispersion Model',
    '4':'NCEP/ARL Smoke Model',
    '5':'Satellite Derived Precipitation and temperatures, from IR (See PDS Octet 41 ... for specific satellite ID)',
    '6':'NCEP/ARL Dust Model',
    '7-9':'Reserved',
    '10':'Global Wind-Wave Forecast Model',
    '11':'Global Multi-Grid Wave Model (Static Grids)',
    '12':'Probabilistic Storm Surge (P-Surge)',
    '13':'Hurricane Multi-Grid Wave Model',
    '14':'Extra-tropical Storm Surge Atlantic Domain',
    '15':'Nearshore Wave Prediction System (NWPS)',
    '16':'Extra-Tropical Storm Surge (ETSS)',
    '17':'Extra-tropical Storm Surge Pacific Domain',
    '18':'Probabilistic Extra-Tropical Storm Surge (P-ETSS)',
    '19':'Reserved',
    '20':'Extra-tropical Storm Surge Micronesia Domain',
    '21-24':'Reserved',
    '25':'Snow Cover Analysis',
    '26-29':'Reserved',
    '30':'Forecaster generated field',
    '31':'Value added post processed field',
    '32-41':'Reserved',
    '42':'Global Optimum Interpolation Analysis (GOI) from GFS model',
    '43':'Global Optimum Interpolation Analysis (GOI) from "Final" run',
    '44':'Sea Surface Temperature Analysis',
    '45':'Coastal Ocean Circulation Model',
    '46':'HYCOM - Global',
    '47':'HYCOM - North Pacific basin',
    '48':'HYCOM - North Atlantic basin',
    '49':'Ozone Analysis from TIROS Observations',
    '50-51':'Reserved',
    '52':'Ozone Analysis from Nimbus 7 Observations',
    '53-63':'Reserved',
    '64':'Regional Optimum Interpolation Analysis (ROI)',
    '65-67':'Reserved',
    '68':'80 wave triangular, 18-layer Spectral model from GFS model',
    '69':'80 wave triangular, 18 layer Spectral model from "Medium Range Forecast" run',
    '70':'Quasi-Lagrangian Hurricane Model (QLM)',
    '71':'Hurricane Weather Research and Forecasting (HWRF)',
    '72':'Hurricane Non-Hydrostatic Multiscale Model on the B Grid (HNMMB)',
    '73':'Fog Forecast model - Ocean Prod. Center',
    '74':'Gulf of Mexico Wind/Wave',
    '75':'Gulf of Alaska Wind/Wave',
    '76':'Bias corrected Medium Range Forecast',
    '77':'126 wave triangular, 28 layer Spectral model from GFS model',
    '78':'126 wave triangular, 28 layer Spectral model from "Medium Range Forecast" run',
    '79':'Reserved',
    '80':'62 wave triangular, 28 layer Spectral model from "Medium Range Forecast" run',
    '81':'Analysis from GFS (Global Forecast System)',
    '82':'Analysis from GDAS (Global Data Assimilation System)',
    '83':'High Resolution Rapid Refresh (HRRR)',
    '84':'MESO NAM Model (currently 12 km)',
    '85':'Real Time Ocean Forecast System (RTOFS)',
    '86':'Early Hurricane Wind Speed Probability Model',
    '87':'CAC Ensemble Forecasts from Spectral (ENSMB)',
    '88':'NOAA Wave Watch III (NWW3) Ocean Wave Model',
    '89':'Non-hydrostatic Meso Model (NMM) (Currently 8 km)',
    '90':'62 wave triangular, 28 layer spectral model extension of the "Medium Range Forecast" run',
    '91':'62 wave triangular, 28 layer spectral model extension of the GFS model',
    '92':'62 wave triangular, 28 layer spectral model run from the "Medium Range Forecast" final analysis',
    '93':'62 wave triangular, 28 layer spectral model run from the T62 GDAS analysis of the "Medium Range Forecast" run',
    '94':'T170/L42 Global Spectral Model from MRF run',
    '95':'T126/L42 Global Spectral Model from MRF run',
    '96':'Global Forecast System Model  T1534 - Forecast hours 00-384 T574 - Forecast hours 00-192 T190 - Forecast hours 204-384',
    '97':'Reserved',
    '98':'Climate Forecast System Model -- Atmospheric model (GFS) coupled to a multi level ocean model . Currently GFS spectral model at T62, 64 levels coupled to 40 level MOM3 ocean model.',
    '99':'Miscellaneous Test ID',
    '100':'Miscellaneous Test ID',
    '101':'Conventional Observation Re-Analysis (CORE)',
    '102-103':'Reserved',
    '104':'National Blend GRIB',
    '105':'Rapid Refresh (RAP)',
    '106':'Reserved',
    '107':'Global Ensemble Forecast System (GEFS)',
    '108':'Localized Aviation MOS Program (LAMP)',
    '109':'Real Time Mesoscale Analysis (RTMA)',
    '110':'NAM Model - 15km version',
    '111':'NAM model, generic resolution (Used in SREF processing)',
    '112':'WRF-NMM model, generic resolution (Used in various runs) NMM=Nondydrostatic Mesoscale Model (NCEP)',
    '113':'Products from NCEP SREF processing',
    '114':'NAEFS Products from joined NCEP, CMC global ensembles',
    '115':'Downscaled GFS from NAM eXtension',
    '116':'WRF-EM model, generic resolution (Used in various runs) EM - Eulerian Mass-core (NCAR - aka Advanced Research WRF)',
    '117':'NEMS GFS Aerosol Component',
    '118':'UnRestricted Mesoscale Analysis (URMA)',
    '119':'WAM (Whole Atmosphere Model)',
    '120':'Ice Concentration Analysis',
    '121':'Western North Atlantic Regional Wave Model',
    '122':'Alaska Waters Regional Wave Model',
    '123':'North Atlantic Hurricane Wave Model',
    '124':'Eastern North Pacific Regional Wave Model',
    '125':'North Pacific Hurricane Wave Model',
    '126':'Sea Ice Forecast Model',
    '127':'Lake Ice Forecast Model',
    '128':'Global Ocean Forecast Model',
    '129':'Global Ocean Data Analysis System (GODAS)',
    '130':'Merge of fields from the RUC, NAM, and Spectral Model',
    '131':'Great Lakes Wave Model',
    '132':'High Resolution Ensemble Forecast (HREF)',
    '133':'Great Lakes Short Range Wave Model',
    '134':'Rapid Refresh Forecast System (RRFS)',
    '135':'Hurricane Analysis and Forecast System (HAFS)',
    '136-139':'Reserved',
    '140':'North American Regional Reanalysis (NARR)',
    '141':'Land Data Assimilation and Forecast System',
    '142-149':'Reserved',
    '150':'NWS River Forecast System (NWSRFS)',
    '151':'NWS Flash Flood Guidance System (NWSFFGS)',
    '152':'WSR-88D Stage II Precipitation Analysis',
    '153':'WSR-88D Stage III Precipitation Analysis',
    '154-179':'Reserved',
    '180':'Quantitative Precipitation Forecast generated by NCEP',
    '181':'River Forecast Center Quantitative Precipitation Forecast mosaic generated by NCEP',
    '182':'River Forecast Center Quantitative Precipitation estimate mosaic generated by NCEP',
    '183':'NDFD product generated by NCEP/HPC',
    '184':'Climatological Calibrated Precipitation Analysis (CCPA)',
    '185-189':'Reserved',
    '190':'National Convective Weather Diagnostic generated by NCEP/AWC',
    '191':'Current Icing Potential automated product genterated by NCEP/AWC',
    '192':'Analysis product from NCEP/AWC',
    '193':'Forecast product from NCEP/AWC',
    '194':'Reserved',
    '195':'Climate Data Assimilation System 2 (CDAS2)',
    '196':'Climate Data Assimilation System 2 (CDAS2) - used for regeneration runs',
    '197':'Climate Data Assimilation System (CDAS)',
    '198':'Climate Data Assimilation System (CDAS) - used for regeneration runs',
    '199':'Climate Forecast System Reanalysis (CFSR) -- Atmospheric model (GFS) coupled to a multi level ocean, land and seaice model. GFS spectral model at T382, 64 levels coupled to 40 level MOM4 ocean model.',
    '200':'CPC Manual Forecast Product',
    '201':'CPC Automated Product',
    '202-209':'Reserved',
    '210':'EPA Air Quality Forecast - Currently North East US domain',
    '211':'EPA Air Quality Forecast - Currently Eastern US domain',
    '212-214':'Reserved',
    '215':'SPC Manual Forecast Product',
    '216-219':'Reserved',
    '220':'NCEP/OPC automated product',
    '221-230':'Reserved for WPC products',
    '231-254':'Reserved',
    '255':'Missing',
    }